Fetch embeddings (Hugging Face utility)
util_fetch_embeddings(
corpus,
by,
api_token,
api_url = "https://router.huggingface.co/hf-inference/models/BAAI/bge-small-en-v1.5"
)A numeric matrix with row names derived from by.
A data frame or data.table with a text column.
Character vector of column names that identify each text unit.
Your Hugging Face API token.
The inference endpoint URL.